@@ -123,8 +123,9 @@ void prefs_base_folder_changed (GtkWidget *chooser, gpointer user_data)
   current_uri = gconf_client_get_string (gconf_client, GCONF_BASEURI, NULL);
   new_uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser)); 
 
-  if (strcmp(current_uri, new_uri) != 0)  
-    gconf_client_set_string (gconf_client, GCONF_BASEURI, new_uri, NULL);
+  if (current_uri == NULL || strcmp(current_uri, new_uri) != 0) {
+      gconf_client_set_string (gconf_client, GCONF_BASEURI, new_uri, NULL);
+  }
   
   g_free (new_uri);
   g_free (current_uri);
@@ -203,14 +204,9 @@ static void baseuri_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *
   } else {
     g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
     current_uri = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (basepath_fcb));
-    if (current_uri == NULL || strcmp (current_uri, base_uri) != 0) { 
-	    char *dir;
-
-	    dir = sj_get_default_music_directory ();
-	    gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (basepath_fcb), dir);
-	    g_free (dir);
-		
-    }
+    if (current_uri == NULL || strcmp (current_uri, base_uri) != 0) 
+      gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (basepath_fcb), base_uri);
+    
   }
 }
 
