@@ -78,6 +78,7 @@ typedef enum {
 typedef enum {
   STATE_IDLE,
   STATE_PLAYING,
+  STATE_PAUSED,
   STATE_EXTRACTING
 } TrackState;
 
@@ -168,8 +169,6 @@ void sj_debug (SjDebugDomain domain, const gchar* format, ...);
 /**
  * Custom stock icons
  */
-#define SJ_STOCK_PLAYING "sj-stock-playing"
-#define SJ_STOCK_RECORDING "sj-stock-recording"
 #define SJ_STOCK_EXTRACT "sj-stock-extract"
 
 /* TODO: need to add a SjWindow object or something */
